@@ -12,6 +12,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from memphis.memphis import Memphis, Headers, MemphisError, MemphisConnectError, MemphisSchemaError, MemphisHeaderError
 import memphis.retention_types
 import memphis.storage_types
+from memphis.memphis import (
+    Headers,
+    Memphis,
+    MemphisConnectError,
+    MemphisError,
+    MemphisHeaderError,
+    MemphisSchemaError,
+)
